# crustal

Crude Rough Unfinished Seismological Toolbox And Library

### Installation

If you are installing in a new conda environment (always a good idea)
you may need to install pip

    conda install -n *your_environment* pip

First install the GaMMA associator

    pip install git+https://github.com/wayneweiqiang/GaMMA.git

And then

    pip install crustal

This will also install all other dependencies

